<?php

/**
* Quizzes Table Controller
*
* @link 		https://entusiastics.com
* @since 		1.0.0
*
* @package 	Entusiastics_Quiz_Game
* @subpackage 	Entusiastics_Quiz_Game/admin/controllers
*/

if( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class QuizzesTableController extends WP_List_Table {

	function __construct(){

		global $status, $page;

		parent::__construct( array(
			'singular'  => __( 'Quizz', 'entusiastics-quiz-game' ),
			'plural'    => __( 'Quizzes', 'entusiastics-quiz-game' ),
			'ajax'      => false
		));

	}


	function no_items() {
		_e('Aún no hay ningún Quizz creado.', 'entusiastics-quiz-game');
	}

	function column_default( $item, $column_name ) {

		switch( $column_name ) { 
			case 'title':
			case 'description_text':
			case 'duration':
			case 'shortcode':
			case 'category':
			case 'question':
			return $item[ $column_name ];
			default:
			return print_r( $item, true );
		}

	}

	function get_sortable_columns() {

		$sortable_columns = array(
			'title'  => array('title',false),
			'category'   => array('category_id',false),
		);
		return $sortable_columns;

	}

	function get_columns(){

		$columns = array(
			'cb'        => '<input type="checkbox" />',
			'title' => __( 'Título del Quizz', 'entusiastics-quiz-game' ),
			'shortcode'    => __( 'Shortcode del Quizz', 'entusiastics-quiz-game' ),
			'question'      => __( 'Preguntas', 'entusiastics-quiz-game' ),
			'category'      => __( 'Categoría', 'entusiastics-quiz-game' ),
			'duration'      => __( 'Duración', 'entusiastics-quiz-game' ),
			'description_text'      => __( 'Descripción', 'entusiastics-quiz-game' ),
		);

		return $columns;

	}

	function usort_reorder( $a, $b ) {
  		// If no sort, default to title
		$orderby = ( ! empty( $_GET['orderby'] ) ) ? $_GET['orderby'] : 'title';
  		// If no order, default to asc
		$order = ( ! empty($_GET['order'] ) ) ? $_GET['order'] : 'asc';
  		// Determine sort order
		$result = strcmp( $a[$orderby], $b[$orderby] );
  		// Send final sort direction to usort
		return ( $order === 'asc' ) ? $result : -$result;
	}

	function column_shortcode($item) {
		return sprintf('<input type="text" id="shortcode-%1$s" size="12" value="[entusiastics-quiz-game %1$s]" readonly onclick="copyShortcodeToCliboard(%1$s);"><span id="span-shortcode-%1$s" style="display:none">%2$s</span>', $item['id'], __('Copiado en el Portapapeles', 'entusiastics-quiz-game'));
	}

	function column_question($item) {
		$button_text = __('Ver preguntas', 'entusiastics-quiz-game');
		return sprintf('<a href="admin.php?page=entusiastics-quiz-game-questions&quiz_id=%1$d">%2$s</a>', $item['id'], $button_text);
	}

	function column_category($item) {

		global $wpdb;

		$category_id = $item['category_id'];
		$order_by = 'id';
		$sql = $wpdb->prepare("SELECT name, id FROM ".ENTUSIASTICS_QUIZ_GAME_CATEGORIES." ORDER BY %s", $order_by);
		$categories = $wpdb->get_results($sql);
		$text = '';
		$matches = 0;

		foreach ($categories as $category) {
			if ($category_id == $category->id) {
				$matches = 1;
				$text = $category->name;
			}	
		}

		if($matches == 0) {
			$text = __('Sin categorizar', 'entusiastics-quiz-game');
		}

		return sprintf('%1$s', $text);
	}

	function column_title($item){

		$title = $item['title'];

		if(!empty($item['post'])) {
			$title = "<a href='".get_permalink($item['post']['ID'])."'>".$title."</a>";
		}

		$edit_word = __('Editar', 'entusiastics-quiz-game');
		$copy_word = __('Copiar', 'entusiastics-quiz-game');
		$delete_word = __('Borrar', 'entusiastics-quiz-game');

		$actions = array(
			'edit' => sprintf('<a href="admin.php?page=entusiastics-quiz-game-quizz&action=edit&id=%d">%s</a>', $item['id'], $edit_word),
			'copy' => sprintf('<a href="admin.php?page=entusiastics-quiz-game-quizz&action=copy&id=%d">%s</a>', $item['id'], $copy_word),
			'delete' => sprintf('<a class="entusiastics_delete_quizz_item_link" href="javascript:void(0)" alt="Delete item" data-delete="%d">%s</a>', $item['id'], $delete_word),
		);

		return sprintf('%1$s %2$s', $title, $this->row_actions($actions));
	}

	function get_bulk_actions() {
		$actions = array(
			'delete'    => __('Borrar', 'entusiastics-quiz-game')
		);
		return $actions;
	}

	public function process_bulk_action() {

        // security check!
		if ( isset( $_POST['_wpnonce'] ) && ! empty( $_POST['_wpnonce'] ) ) {

			$nonce  = filter_input( INPUT_POST, '_wpnonce', FILTER_SANITIZE_STRING );
			$action = 'bulk-' . $this->_args['plural'];

			if ( ! wp_verify_nonce( $nonce, $action ) )
				wp_die( 'Nope! Security check failed!' );

		}

		$action = $this->current_action();

		switch ( $action ) {

			case 'delete':

			$quizzes = $_POST['quizz'];
			$_quiz = new Quiz();
			$_quiz->bulkDelete($quizzes);
			
			break;
			default:
			return;
			break;
		}

		return;
	}

	function column_cb($item) {
		return sprintf(
			'<input type="checkbox" name="quizz[]" value="%s" />', $item['id']
		);    
	}

	function prepare_items() {

		$search_term = "";

		// Get the search param
		if(isset($_REQUEST["s"])){ 
			$search_term = $_REQUEST["s"];
		}

		$data = $this->getQuizzesList($search_term);

		$quizzes = $this->object_to_array($data['quizzes']);

		if(!empty($data['categories'])) {
			$categories = $this->object_to_array($data['categories']);
		}	
		
		$columns  = $this->get_columns();
		$hidden   = array();
		$sortable = $this->get_sortable_columns();
		$this->_column_headers = $this->get_column_info();
		usort( $quizzes, array( &$this, 'usort_reorder' ) );

		$per_page = $this->get_items_per_page( 'quizzes_per_page', 5 );
		$current_page = $this->get_pagenum();
		$total_items = count($quizzes);

		$found_data = array_slice( $quizzes, ( ( $current_page - 1 ) * $per_page ), $per_page );

		$this->set_pagination_args( array(
			'total_items' => $total_items,
			'per_page' => $per_page
		));

		$this->process_bulk_action();

		$this->items = $found_data;
	}

	function object_to_array($data)
	{
		if (is_array($data) || is_object($data))
		{
			$result = array();
			foreach ($data as $key => $value)
			{
				$result[$key] = $this->object_to_array($value);
			}
			return $result;
		}
		return $data;
	}

	static function render_quizzes_list(){

		$quizzes_list_table = new QuizzesTableController();

		$quizzes_list_table->prepare_items();

		include(ENTUSIASTICS_QUIZ_GAME_PLUGIN_PATH."admin/partials/entusiastics-quiz-game-quizzes.php");
	}

	function getQuizzesList($search_term){

		global $wpdb;

		$data = [
			'quizzes' => [],
			'posts' => []
		];

		$order_by = 'created_at';

		$sql = $wpdb->prepare("SELECT * FROM ".ENTUSIASTICS_QUIZ_GAME_QUIZZES." ORDER BY %s DESC", $order_by);

		// select quizzes
		if($search_term != '') {
			$sql = $wpdb->prepare("SELECT * FROM ".ENTUSIASTICS_QUIZ_GAME_QUIZZES." WHERE title LIKE %1$s OR description_text LIKE %1$s ORDER BY %2$s DESC", "%".$search_term."%", $order_by);
		}

		$data['quizzes'] = $wpdb->get_results($sql);

		// now select all posts that have entusiastics-quiz-game shortcode in them
		$data['posts'] = $wpdb->get_results("SELECT * FROM {$wpdb->posts} WHERE post_content LIKE '%[entusiastics-quiz-game %]%' AND post_title!='' AND post_status='publish' ORDER BY post_date DESC");	

		// match posts to exams
		foreach($data['quizzes'] as $cnt => $quiz) {

			foreach($data['posts'] as $post) {

				if(strstr($post->post_content, "[entusiastics-quiz-game ".$quiz->id."]")) {

					$data['quizzes'][$cnt]->post = $post;			
					break;
					
				}

			}
		}

		return $data;
	}


} //class