<?php

/**
 * Fired during plugin instalation
 *
 * @link 		https://lin3s.com
 * @since 		1.0.0
 *
 * @package 	Entusiastics_Quiz_Game
 * @subpackage 	Entusiastics_Quiz_Game/includes
 */

class Entusiastics_Quiz_Game_Cpt {

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since 		1.0.0
	 * @access 		public
	 * @var 		string 			$plugin_name 		The string used to uniquely identify this plugin.
	 */
	public $cutoms_taxonomies_list;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since 		1.0.0
	 * @access 		public
	 * @var 		string 			$plugin_name 		The string used to uniquely identify this plugin.
	 */
	public $custom_posts_types_list;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since 		1.0.0
	 * @access 		public
	 * @var 		string 			$plugin_name 		The string used to uniquely identify this plugin.
	 */
	public $plugin_name;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since 		1.0.0
	 * @access 		public
	 * @var 		string 			$plugin_name 		The string used to uniquely identify this plugin.
	 */
	public $version;

	/**
	 * Initialize the custom post type list
	 *
	 * @since 		1.0.0
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

		$this->custom_posts_types_list = [
			'num_post_types' => 16,
			'post_types' => [

				'singular' => [
					'Quizz',
					'Pregunta',
					'Perfile',
					'Completado'
				],

				'plural' => [
					'Quizzes',
					'Preguntas',
					'Perfiles',
					'Completados'
				],

				'post_type_name' => [
					'quizz',
					'question',
					'profile',
					'completed'
				]

			]
		];


		$this->cutoms_taxonomies_list = [
			'num_taxonomies' => 3,
			'taxonomies' => [

				'singular' => [
					'Categoría Quizz'
				],

				'plural' => [
					'Categorías Quizzes'
				],

				'taxonomy_name' => [
					'quizzes-categories'
				],

				'post_type_name' => [
					'quizz'
				]

			]
		];

	}

	/**
	 * Register all custom taxonomies of the plugin.
	 *
	 * @since 		1.0.0
	 * @access 		public
	 */
	public function register_custom_post_types() {

		$cutom_post_types_list = $this->custom_posts_types_list;

		for ( $i=0; $i <= ($cutom_post_types_list['num_post_types'] - 1); $i++) {

			$post_type_name = $cutom_post_types_list['post_types']['post_type_name'][$i];
			$singular = $cutom_post_types_list['post_types']['singular'][$i];
			$plural = $cutom_post_types_list['post_types']['plural'][$i];

			$labels = array(
				'name'                  => _x( $plural, 'Post Type General Name', 'entusiastics-quiz-game' ),
				'singular_name'         => _x( $singular, 'Post Type Singular Name', 'entusiastics-quiz-game' ),
				'add_new'               => __( 'Nuevo '.$singular, 'entusiastics-quiz-game' ),
				'add_new_item'          => __( 'Añadir Nuevo '.$singular, 'entusiastics-quiz-game' ),
				'edit_item'             => __( 'Editar '.$singular, 'entusiastics-quiz-game' ),
				'new_item'              => __( 'Nuevo '.$singular, 'entusiastics-quiz-game' ),
				'view_item'             => __( 'Ver '.$singular, 'entusiastics-quiz-game' ),
				'view_items'            => __( 'Ver '.$plural, 'entusiastics-quiz-game' ),
				'search_items'          => __( 'Buscar '.$plural, 'entusiastics-quiz-game' ),
				"not_found"             => "No plural Found",
				"not_found_in_trash"    => "No plural Found in Trash",
				'all_items'             => "All plural",
				'attributes'            => "singular Attributes",
				'insert_into_item'      => "Insert to singular",
				'uploaded_to_this_item' => "Uploaded to this singular"
			);

			$supports = array('title');

			if($post_type_name === 'objectives' || $post_type_name === 'objectives_builder' || $post_type_name === 'builder_examples') {

				$supports = array('title', 'editor');

			}

			$args = array(
				'label'               => $singular,
				'description'         => __( $singular.' del plugin de Alexandria', 'entusiastics-quiz-game' ),
				'labels'              => $labels,
				'supports'            => $supports,
				'hierarchical'        => false,
				'public'              => false,
				'show_ui'             => true,
				'show_in_menu'        => false,
				'show_in_nav_menus'   => false,
				'show_in_admin_bar'   => false,
				'menu_position'       => 30,
				'can_export'          => true,
				'has_archive'         => true,
				'exclude_from_search' => true,
				'publicly_queryable'  => false,
				'capability_type'     => 'post',
				'show_in_rest' 		  => true
			);

			register_post_type($post_type_name, $args);
		}

	}


	/**
	 * Register all custom taxonomies of the plugin.
	 *
	 * @since 		1.0.0
	 * @access 		public
	 */
	public function register_custom_taxonomies() {

		$cutoms_taxonomies_list = $this->cutoms_taxonomies_list;

		for ( $i=0; $i <= ($cutoms_taxonomies_list['num_taxonomies'] - 1); $i++) {

			$taxonomy_name = $cutoms_taxonomies_list['taxonomies']['taxonomy_name'][$i];
			$singular = $cutoms_taxonomies_list['taxonomies']['singular'][$i];
			$plural = $cutoms_taxonomies_list['taxonomies']['plural'][$i];
			$post_type_name = $cutoms_taxonomies_list['taxonomies']['post_type_name'][$i];

			register_taxonomy( $taxonomy_name,
				array (0 => $post_type_name),
				array(
					'hierarchical'      		 => true,
					'label'             		 => __( $singular, 'entusiastics-quiz-game' ),
					'show_ui'           		 => true,
					'query_var'         		 => true,
					'show_admin_column' 		 => true,
					'sortable' 					 => true,
					'labels'            		 => array (
						'search_items'               => __('Buscar '.$plural, 'entusiastics-quiz-game'),
						'popular_items'              => __('Más Populares', 'entusiastics-quiz-game'),
						'all_items'                  => __('Todas las '.$plural, 'entusiastics-quiz-game'),
						'parent_item'                => __('Superior', 'entusiastics-quiz-game'),
						'parent_item_colon'          => __( $singular.' Superior', 'entusiastics-quiz-game'),
						'edit_item'                  => __('Editar '.$singular, 'entusiastics-quiz-game'),
						'update_item'                => __('Actualizar '.$singular, 'entusiastics-quiz-game'),
						'add_new_item'               => __('Añadir '.$singular, 'entusiastics-quiz-game'),
						'new_item_name'              => __('Nueva '.$singular, 'entusiastics-quiz-game'),
						'separate_items_with_commas' => __('Separar categorías con comas', 'entusiastics-quiz-game'),
						'add_or_remove_items'        => __('Añadir o Eliminar', 'entusiastics-quiz-game'),
						'choose_from_most_used'      => __('Elegir de las categorías más usadas', 'entusiastics-quiz-game'),
					)
				));

		}

	} // define_custom_taxonomies()

	/**
	 * Register all metaboxes of the plugin.
	 *
	 * @since 		1.0.0
	 * @access 		public
	 */
	public function define_custom_post_type_mataboxes() {

		// Conversations Metaboxes
		$conversations_metaboxes = new Alexandria_Conversation_Conversations_Metaboxes( $this->plugin_name, $this->version );

		add_meta_box('interlocutor_metabox', __( 'Interlocutor de la Conversación', 'entusiastics-quiz-game' ), array( $conversations_metaboxes, 'interlocutor_fields' ), 'conversations' );
		
		add_meta_box('tono_metabox', __( 'Tono de la Conversación', 'entusiastics-quiz-game' ), array( $conversations_metaboxes, 'tono_fields' ), 'conversations' );

		add_meta_box('situation_metabox', __( 'Situación de la Conversación', 'entusiastics-quiz-game' ), array( $conversations_metaboxes, 'situation_fields' ), 'conversations' );

		add_meta_box('objectives_metabox', __( 'Objetivo de la Conversación', 'entusiastics-quiz-game' ), array( $conversations_metaboxes, 'objectives_fields' ), 'conversations' );

		add_meta_box('soliloquios_metabox', __( 'Soliloquios de la Conversación', 'entusiastics-quiz-game' ), array( $conversations_metaboxes, 'soliloquios_fields' ), 'conversations' );

		add_meta_box('conclusions_metabox', __( 'Conclusiones de la Conversación', 'entusiastics-quiz-game' ), array( $conversations_metaboxes, 'conclusions_fields' ), 'conversations' );

		add_meta_box('decisions_metabox', __( 'Decisiones de la Conversación', 'entusiastics-quiz-game' ), array( $conversations_metaboxes, 'decisions_fields' ), 'conversations' );

		add_meta_box('expect_results_metabox', __( 'Resultados Esperados de la Conversación', 'entusiastics-quiz-game' ), array( $conversations_metaboxes, 'expect_results_fields' ), 'conversations' );

		add_meta_box('strong_questions_metabox', __( 'Preguntas Potentes de la Conversación', 'entusiastics-quiz-game' ), array( $conversations_metaboxes, 'strong_questions_fields' ), 'conversations' );

		add_meta_box('relevance_metabox', __( 'Relevancia de la Conversación', 'entusiastics-quiz-game' ), array( $conversations_metaboxes, 'relevance_fields' ), 'conversations' );

		add_meta_box('argumentos_metabox', __( 'Argumentos de la Conversación', 'entusiastics-quiz-game' ), array( $conversations_metaboxes, 'argumentos_fields' ), 'conversations' );

		add_meta_box('viable_minimal_metabox', __( 'Mínimos Viables de la Conversación', 'entusiastics-quiz-game' ), array( $conversations_metaboxes, 'viable_minimal_fields' ), 'conversations' );

		add_meta_box('comentarios_metabox', __( 'Comentarios de la Conversación', 'entusiastics-quiz-game' ), array( $conversations_metaboxes, 'comentarios_fields' ), 'conversations' );

		add_meta_box('examples_metabox', __( 'Ejemplos de la Conversación', 'entusiastics-quiz-game' ), array( $conversations_metaboxes, 'examples_fields' ), 'conversations' );
		

		// Tonos Metaboxes
		$tono_metabox = new Alexandria_Conversation_Tonos_Metaboxes( $this->plugin_name, $this->version );

		add_meta_box('tonos-colors-metabox', __('Colores de la Emoción', 'entusiastics-quiz-game' ), array( $tono_metabox, 'alexandria_tonos_colors_meta_box' ), 'tonos');

		// Strong Questions Metaboxes
		$strong_questions_video_metabox = new Alexandria_Conversation_Preguntas_Potentes_Metaboxes( $this->plugin_name, $this->version );

		add_meta_box('strong-questions-video-metabox', __('Video de la Pregunta Potente', 'entusiastics-quiz-game' ), array( $strong_questions_video_metabox, 'alexandria_preguntas_potentes_colors_meta_box' ), 'strong_questions');

		remove_meta_box('strong_questions-categoriesdiv', 'strong_questions', 'side');

		add_meta_box('strong_questions-categoriesdiv', __('Categories'), 'post_categories_meta_box' , 'strong_questions', 'normal', 'low', array('taxonomy' => 'strong_questions-categories'));

		// Tonos Metaboxes
		$interlocutors_metabox = new Alexandria_Conversation_Interlocutors_Metaboxes( $this->plugin_name, $this->version );

		add_meta_box('interlocutors-metabox', __('Ordern del interlocutor', 'entusiastics-quiz-game' ), array( $interlocutors_metabox, 'alexandria_interlocutors_meta_box' ), 'interlocutors');


	} // define_custom_post_type_mataboxes()
}
